@@ -9,8 +9,8 @@ module Grape
       class Base
         attr_reader :attribute, :is_safe, :documentation, :override, :conditions, :for_merge
 
-        def self.new(attribute, options, conditions, *args, &block)
-          super(attribute, options, conditions).tap { |e| e.setup(*args, &block) }
+        def self.new(attribute, options, conditions, ...)
+          super(attribute, options, conditions).tap { |e| e.setup(...) }
         end
 
         def initialize(attribute, options, conditions)
@@ -89,7 +89,7 @@ module Grape
           return unless valid?(entity)
 
           output = value(entity, options)
-          output.blank? && @default_value.present? ? @default_value : output
+          output.blank? && !@default_value.nil? ? @default_value : output
         end
 
         def should_return_key?(options)
